@@ -152,6 +152,7 @@ class EWAHBaseOperator(BaseOperator):
         cleaner_class=EWAHCleaner,
         cleaner_callables=None,  # callables or list of callables to run during cleaning
         uploader_class=None,  # Future: deprecate dwh_engine and use this kwarg instead
+        additional_uploader_kwargs=None,
         deduplication_before_upload=False,
         *args,
         **kwargs
@@ -292,6 +293,7 @@ class EWAHBaseOperator(BaseOperator):
         self.deduplication_before_upload = deduplication_before_upload
 
         self.uploader_class = uploader_class or get_uploader(self.dwh_engine)
+        self.additional_uploader_kwargs = additional_uploader_kwargs or {}
 
         _msg = "DWH hook does not support extract strategy {0}!".format(
             extract_strategy,
@@ -377,6 +379,7 @@ class EWAHBaseOperator(BaseOperator):
             pickling_upload_chunk_size=self.pickling_upload_chunk_size,
             pickle_compression=self.pickle_compression,
             deduplication_before_upload=self.deduplication_before_upload,
+            **self.additional_uploader_kwargs,
         )
 
         # If applicable: set the session's default time zone
